==> ExtendedAE-1.20-0.1.31-forge.jar: assets/expatternprovider/ae2guide/epp_intro/pattern_modifier.md <==
---
navigation:
    parent: epp_intro/epp_intro-index.md
    title: Pattern Modifier
    icon: expatternprovider:pattern_modifier
categories:
- extended items
item_ids:
- expatternprovider:pattern_modifier
---

# Pattern Modifier

Pattern Modifier is a tool for bulk pattern modification.

<ItemImage id="expatternprovider:pattern_modifier" scale="4"></ItemImage>

Right click it to open its GUI.

## Multiply Mode

You can multiply/divide processing pattern's input and output amount by x by clicking the corresponding button. 

![PM](../pic/pm.png)

Origin Pattern:

![PM1](../pic/pm1.png)

After x10:

![PM2](../pic/pm2.png)

It also can clear all patterns contents and turn them into blank patterns by clicking the Clear button.

### Notes:

 - The division button only works when its amount is divisible. For example ÷2 button won't work when pattern requires 3x
cobblestones as input, because 3÷2 is 1.5.

 - The multiplication button has a cap(999999). It can't make single ingredient's amount over this number.

## Replace Mode

Replace processing pattern's certain input and output ingredient with the other item.

![PM3](../pic/pm4.png)

The slot A is what will be replaced and slot B is what the target will be replaced with.

For example, the following setting will replace the plank with coal.

![PM4](../pic/pm6.png)

![PM5](../pic/pm5.png)

Click the Replace button to perform the replacement.

![PM6](../pic/pm7.png)

## Clone Mode

You make copy any give pattern in this mode.

![PM7](../pic/pm3.png)

==> ExtendedAE-1.20-1.4.2-forge.jar: assets/expatternprovider/ae2guide/epp_intro/pattern_modifier.md <==
---
navigation:
    parent: epp_intro/epp_intro-index.md
    title: Pattern Modifier
    icon: expatternprovider:pattern_modifier
categories:
- extended items
item_ids:
- expatternprovider:pattern_modifier
---

# Pattern Modifier

Pattern Modifier is a tool for bulk pattern modification.

<ItemImage id="expatternprovider:pattern_modifier" scale="4"></ItemImage>

Right click it to open its GUI.

## Multiply Mode

You can multiply/divide processing pattern's input and output amount by x by clicking the corresponding button. 

![PM](../pic/pm.png)

Origin Pattern:

![PM1](../pic/pm1.png)

After x10:

![PM2](../pic/pm2.png)

It also can clear all patterns contents and turn them into blank patterns by clicking the Clear button.

### Notes:

 - The division button only works when its amount is divisible. For example ÷2 button won't work when pattern requires 3x
cobblestones as input, because 3÷2 is 1.5.

 - The multiplication button has a cap(999999). It can't make single ingredient's amount over this number.

## Replace Mode

Replace pattern's certain input and output ingredient with the other item.

![PM3](../pic/pm4.png)

The slot A is what will be replaced and slot B is what the target will be replaced with.

For example, the following setting will replace the plank with coal.

![PM4](../pic/pm6.png)

![PM5](../pic/pm5.png)

Click the Replace button to perform the replacement.

![PM6](../pic/pm7.png)

## Clone Mode

You make copy any give pattern in this mode.

![PM7](../pic/pm3.png)
